@@ -5,16 +5,11 @@ from typing import Any
 import numpy as np
 import pandas as pd
 from sklearn.base import BaseEstimator, TransformerMixin
-from sklearn.compose import ColumnTransformer
-from sklearn.pipeline import Pipeline
+from sklearn.pipeline import make_pipeline
 
-from rexify.features.dataset import TfDatasetGenerator
-from rexify.features.pipelines import (
-    CategoricalPipeline,
-    IdentifierPipeline,
-    NumericalPipeline,
-    RankingPipeline,
-)
+from rexify.features.dataset import TFDatasetGenerator
+from rexify.features.transform import FeatureTransformer, IDEncoder, Sequencer
+from rexify.types import Schema
 from rexify.utils import (
     get_ranking_features,
     get_schema_features,
@@ -23,7 +18,7 @@ from rexify.utils import (
 )
 
 
-class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
+class FeatureExtractor(BaseEstimator, TransformerMixin, TFDatasetGenerator):
 
     """Main transformer responsible for pre-processing event data.
 
@@ -53,11 +48,18 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
         <MapDataset element_spec={'query': {'user_id': TensorSpec(shape=(), dtype=tf.int64, name=None), 'user_features': TensorSpec(shape=(0,), dtype=tf.float32, name=None), 'context_features': TensorSpec(shape=(0,), dtype=tf.float32, name=None)}, 'candidate': {'item_id': TensorSpec(shape=(), dtype=tf.int64, name=None), 'item_features': TensorSpec(shape=(0,), dtype=tf.float32, name=None)}}>
     """
 
-    _ppl: ColumnTransformer
     _model_params: dict[str, Any]
     _output_features: list[str]
     _rating_add: bool
 
+    def __init__(self, schema: Schema, **kwargs):
+        super().__init__(schema=schema)
+        self._ppl = make_pipeline(
+            IDEncoder(schema=schema),
+            Sequencer(schema=schema, **kwargs),
+            FeatureTransformer(schema=schema, **kwargs),
+        )
+
     def fit(self, X: pd.DataFrame, *_):
         """Fit FeatureExtractor to X.
 
@@ -67,7 +69,6 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
         Returns:
             self: fitted encoder
         """
-        self._ppl = self._make_transformer()
         self._check_rating_col(X)
         self._validate_input(X)
         x_ = self._add_rating_col(X)
@@ -105,26 +106,6 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
     def model_params(self):
         return self._model_params
 
-    def _make_transformer(self) -> ColumnTransformer:
-        transformer_list: list[tuple[str, TransformerMixin, list[str]]] = [
-            *self._get_features_transformers(target="user"),
-            *self._get_features_transformers(target="item"),
-        ]
-
-        transformer_list += (
-            [*self._get_features_transformers(target="context")]
-            if "context" in self.schema.keys()
-            else []
-        )
-
-        transformer_list += (
-            self._get_features_transformers(target="rank")
-            if "rank" in self.schema.keys()
-            else []
-        )
-
-        return ColumnTransformer(transformer_list)
-
     def _get_model_params(self, X):
         user_id = get_target_id(self.schema, "user")[0]
         user_input_dim = int(X[user_id].nunique() + 1)
@@ -140,25 +121,6 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
             "ranking_features": X["event_type"].unique().tolist(),
         }
 
-    def _get_features_transformers(
-        self, target: str
-    ) -> list[tuple[str, Pipeline, list[str]]]:
-        transformer_list = []
-
-        if target != "rank":
-            if target != "context":
-                transformer_list.append(IdentifierPipeline(self.schema, target))
-
-            categorical_ppl = CategoricalPipeline(self.schema, target)
-            transformer_list += [categorical_ppl] if categorical_ppl != tuple() else []
-
-            numerical_ppl = NumericalPipeline(self.schema, target)
-            transformer_list += [numerical_ppl] if numerical_ppl != tuple() else []
-        else:
-            transformer_list.append(RankingPipeline(self.schema, target))
-
-        return transformer_list
-
     def _validate_input(
         self,
         X: pd.DataFrame,
@@ -181,3 +143,6 @@ class FeatureExtractor(BaseEstimator, TransformerMixin, TfDatasetGenerator):
         if self._rating_add:
             x_["rating"] = np.zeros(X.shape[0])
         return x_
+
+    def _get_feature_names_out(self) -> list[str]:
+        return self._ppl.steps[-1][-1].get_feature_names_out()
