@@ -64,9 +64,9 @@ class Recommender(RetrievalMixin, RankingMixin):
         RetrievalMixin.__init__(
             self,
             user_id=user_id,
-            user_dims=user_dims,
+            user_dims=user_dims + 1,
             item_id=item_id,
-            item_dims=item_dims,
+            item_dims=item_dims + 1,
             embedding_dim=embedding_dim,
             feature_layers=feature_layers,
             output_layers=output_layers,
@@ -81,7 +81,7 @@ class Recommender(RetrievalMixin, RankingMixin):
 
     def compute_loss(self, inputs, training: bool = False) -> tf.Tensor:
         embeddings = self(inputs)  # Recommender inherits RetrievalMixin's call method
-        loss = self.get_retrieval_loss(*embeddings)
+        loss = self.retrieval_task(*embeddings)
         loss += self.get_ranking_loss(
             *embeddings, inputs["event_type"], inputs["rating"]
         )
