@@ -1,16 +1,18 @@
 from pathlib import Path
 from typing import Any, List
 
+from rexify.types import Schema
+
 
 def flatten(xss: List[List[Any]]):
     return [x for xs in xss for x in xs]
 
 
-def get_target_id(schema: dict, target: str):
+def get_target_id(schema: Schema, target: str):
     return get_target_feature(schema, target, "id")
 
 
-def get_target_feature(schema: dict, target: str, type_: str):
+def get_target_feature(schema: Schema, target: str, type_: str):
     def mask(x: tuple):
         return x[1] == type_
 
@@ -26,13 +28,9 @@ def get_first(x: tuple):
     return x[0]
 
 
-def get_schema_features(
-    schema: dict[str, dict[str, Any] | list[dict[str, str | float]]]
-):
+def get_schema_features(schema: Schema):
     return flatten([list(v.keys()) for k, v in schema.items() if k != "rank"])
 
 
-def get_ranking_features(
-    schema: dict[str, dict[str, Any] | list[dict[str, str | float]]]
-):
+def get_ranking_features(schema: Schema):
     return [feat["name"] for feat in schema["rank"]]
